AppRemarkMethodChannel class

An implementation of AppRemarkPlatformInterface that uses method channels. This class enables communication with the native platform for the AppsOnAir AppRemark SDK.

Inheritance

Constructors

AppRemarkMethodChannel()

Properties

context ↔ BuildContext
context: Required to show a dialog or overlay.
getter/setter pair
eventChannel → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRemark(BuildContext context) → Future<void>
Manually opens the AppRemark screen.
override
dispose() → void
initialize(BuildContext context, {bool shakeGestureEnable = true, Map<String, dynamic> options = const {}, required dynamic onRemarkResponse(Map<String, dynamic>)}) → Future<void>
Initializes the AppsOnAir AppRemark SDK.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAdditionalMetaData({Map<String, dynamic> extraPayload = const {}}) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited