AppRemarkPlatformInterface class abstract

The platform interface for AppRemark.

This allows communication between the platform-specific implementation and the Flutter application. The concrete implementation of this interface should provide platform-specific functionality, typically by using a MethodChannel to invoke native code.

Inheritance
  • Object
  • PlatformInterface
  • AppRemarkPlatformInterface
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRemark(BuildContext context) → Future<void>
Adds a remark on the platform.
initialize(BuildContext context, {bool shakeGestureEnable = true, Map<String, dynamic> options = const {}, required dynamic onRemarkResponse(Map<String, dynamic>)}) → Future<void>
Initializes the AppRemark platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAdditionalMetaData({Map<String, dynamic> extraPayload = const {}}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ AppRemarkPlatformInterface
The current instance of AppRemarkPlatformInterface.
getter/setter pair